
# SKCAN-Compare
Tool to retrieve and visualize data contained in SCKAN (e.g., across species, relationship to spinal segments) to highlight similarities and differences in neuronal pathways

![SKCAN-Compare](cover_photo.png)

## Project Objective

The SPARC Connectivity Knowledge Base of the Autonomic Nervous System (SCKAN) is a semantic store modeling the topology of nerve-end organ connectivity and acts as a core component of powerful query and visualization capabilities within SPARC.

(add more here...)

## Proposed Solution

Todo


## Video Demo
Todo


## Tutorials
Todo


## Documentation
Todo

## Reporting Issues or Contributions
To report an issue or suggest a new feature, please use the issues page. Please check existing issues before submitting a new one.

## Contribute to Project

You can offer to help with the further development of this project by making pull requests on this repo. To do so, fork this repository and make the proposed changes. Once completed and tested, submit a pull request to this repo. 


## License
Todo


## Team Members
(in alphabetical order)
- [Gautam Kumar](https://github.com/gogu07)
- [Hiba Ben Aribi](https://github.com/HibaBenAribi)
- Lambert Nzungize (?)
- [Pranjal Garg](https://github.com/Neurogarg/)
- [Shailesh Appukuttan](https://github.com/appukuttan-shailesh/)
